[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/nyaml) [![PyPI](https://img.shields.io/pypi/v/nyaml)](https://pypi.org/project/nyaml/) [![Pytest](https://github.com/FAIRmat-NFDI/nyaml/actions/workflows/pytest.yaml/badge.svg)](https://github.com/FAIRmat-NFDI/nyaml/actions/workflows/pytest.yaml)[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.1323437.svg)](https://doi.org/10.5281/zenodo.13860810)


# nyaml Tool for NeXus
The `nyaml` tool is a Python package that provides a command line interface for converting NeXus application definitions
or base classes from the `nxdl.xml` format into the `yaml` format and vice versa.

# Getting started
```
pip install nyaml
```

The converter can be called by the command `nyaml2nxdl`.

You can find the full documentation of the tool [here](https://fairmat-nfdi.github.io/nyaml/).

